Method: Aws::EFS::Client#create_mount_target

Defined in:
lib/aws-sdk-efs/client.rb

#create_mount_target(params = {}) ⇒ Types::MountTargetDescription

Creates a mount target for a file system. You can then mount the file system on EC2 instances by using the mount target.

You can create one mount target in each Availability Zone in your VPC. All EC2 instances in a VPC within a given Availability Zone share a single mount target for a given file system. If you have multiple subnets in an Availability Zone, you create a mount target in one of the subnets. EC2 instances do not need to be in the same subnet as the mount target in order to access their file system.

You can create only one mount target for a One Zone file system. You must create that mount target in the same Availability Zone in which the file system is located. Use the AvailabilityZoneName and AvailabiltyZoneId properties in the DescribeFileSystems response object to get this information. Use the subnetId associated with the file system’s Availability Zone when creating the mount target.

For more information, see [Amazon EFS: How it Works].

To create a mount target for a file system, the file system’s lifecycle state must be available. For more information, see DescribeFileSystems.

In the request, provide the following:

  • The file system ID for which you are creating the mount target.

  • A subnet ID, which determines the following:

    • The VPC in which Amazon EFS creates the mount target

    • The Availability Zone in which Amazon EFS creates the mount target

    • The IP address range from which Amazon EFS selects the IP address of the mount target (if you don’t specify an IP address in the request)

After creating the mount target, Amazon EFS returns a response that includes, a MountTargetId and an IpAddress. You use this IP address when mounting the file system in an EC2 instance. You can also use the mount target’s DNS name when mounting the file system. The EC2 instance on which you mount the file system by using the mount target can resolve the mount target’s DNS name to its IP address. For more information, see [How it Works: Implementation Overview].

Note that you can create mount targets for a file system in only one VPC, and there can be only one mount target per Availability Zone. That is, if the file system already has one or more mount targets created for it, the subnet specified in the request to add another mount target must meet the following requirements:

  • Must belong to the same VPC as the subnets of the existing mount targets

  • Must not be in the same Availability Zone as any of the subnets of the existing mount targets

If the request satisfies the requirements, Amazon EFS does the following:

  • Creates a new mount target in the specified subnet.

  • Also creates a new network interface in the subnet as follows:

    • If the request provides an IpAddress, Amazon EFS assigns that IP address to the network interface. Otherwise, Amazon EFS assigns a free address in the subnet (in the same way that the Amazon EC2 CreateNetworkInterface call does when a request does not specify a primary private IP address).

    • If the request provides SecurityGroups, this network interface is associated with those security groups. Otherwise, it belongs to the default security group for the subnet’s VPC.

    • Assigns the description ‘Mount target fsmt-id for file system fs-id ` where ` fsmt-id ` is the mount target ID, and ` fs-id ` is the FileSystemId.

    • Sets the requesterManaged property of the network interface to true, and the requesterId value to EFS.

    Each Amazon EFS mount target has one corresponding requester-managed EC2 network interface. After the network interface is created, Amazon EFS sets the NetworkInterfaceId field in the mount target’s description to the network interface ID, and the IpAddress field to its address. If network interface creation fails, the entire CreateMountTarget operation fails.

<note markdown=“1”> The CreateMountTarget call returns only after creating the network interface, but while the mount target state is still creating, you can check the mount target creation status by calling the DescribeMountTargets operation, which among other things returns the mount target state.

</note>

We recommend that you create a mount target in each of the Availability Zones. There are cost considerations for using a file system in an Availability Zone through a mount target created in another Availability Zone. For more information, see [Amazon EFS pricing]. In addition, by always using a mount target local to the instance’s Availability Zone, you eliminate a partial failure scenario. If the Availability Zone in which your mount target is created goes down, then you can’t access your file system through that mount target.

This operation requires permissions for the following action on the file system:

  • elasticfilesystem:CreateMountTarget

^

This operation also requires permissions for the following Amazon EC2 actions:

  • ec2:DescribeSubnets

  • ec2:DescribeNetworkInterfaces

  • ec2:CreateNetworkInterface

[1]: docs.aws.amazon.com/efs/latest/ug/how-it-works.html [2]: docs.aws.amazon.com/efs/latest/ug/how-it-works.html#how-it-works-implementation [3]: aws.amazon.com/efs/pricing/

Examples:

Example: To create a new mount target


# This operation creates a new mount target for an EFS file system.

resp = client.create_mount_target({
  file_system_id: "fs-01234567", 
  subnet_id: "subnet-1234abcd", 
})

resp.to_h outputs the following:
{
  file_system_id: "fs-01234567", 
  ip_address: "192.0.0.2", 
  life_cycle_state: "creating", 
  mount_target_id: "fsmt-12340abc", 
  network_interface_id: "eni-cedf6789", 
  owner_id: "012345678912", 
  subnet_id: "subnet-1234abcd", 
}

Request syntax with placeholder values


resp = client.create_mount_target({
  file_system_id: "FileSystemId", # required
  subnet_id: "SubnetId", # required
  ip_address: "IpAddress",
  ipv_6_address: "Ipv6Address",
  ip_address_type: "IPV4_ONLY", # accepts IPV4_ONLY, IPV6_ONLY, DUAL_STACK
  security_groups: ["SecurityGroup"],
})

Response structure


resp.owner_id #=> String
resp.mount_target_id #=> String
resp.file_system_id #=> String
resp.subnet_id #=> String
resp.life_cycle_state #=> String, one of "creating", "available", "updating", "deleting", "deleted", "error"
resp.ip_address #=> String
resp.ipv_6_address #=> String
resp.network_interface_id #=> String
resp.availability_zone_id #=> String
resp.availability_zone_name #=> String
resp.vpc_id #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :file_system_id (required, String)

    The ID of the file system for which to create the mount target.

  • :subnet_id (required, String)

    The ID of the subnet to add the mount target in. For One Zone file systems, use the subnet that is associated with the file system’s Availability Zone.

  • :ip_address (String)

    If the IP address type for the mount target is IPv4, then specify the IPv4 address within the address range of the specified subnet.

  • :ipv_6_address (String)

    If the IP address type for the mount target is IPv6, then specify the IPv6 address within the address range of the specified subnet.

  • :ip_address_type (String)

    Specify the type of IP address of the mount target you are creating. Options are IPv4, dual stack, or IPv6. If you don’t specify an IpAddressType, then IPv4 is used.

    • IPV4_ONLY – Create mount target with IPv4 only subnet or dual-stack subnet.

    • DUAL_STACK – Create mount target with dual-stack subnet.

    • IPV6_ONLY – Create mount target with IPv6 only subnet.

    <note markdown=“1”> Creating IPv6 mount target only ENI in dual-stack subnet is not supported.

    </note>
    
  • :security_groups (Array<String>)

    VPC security group IDs, of the form sg-xxxxxxxx. These must be for the same VPC as the subnet specified. The maximum number of security groups depends on account quota. For more information, see [Amazon VPC Quotas] in the *Amazon VPC User Guide* (see the **Security Groups** table).

    [1]: docs.aws.amazon.com/vpc/latest/userguide/amazon-vpc-limits.html

Returns:

See Also:



1184
1185
1186
1187
# File 'lib/aws-sdk-efs/client.rb', line 1184

def create_mount_target(params = {}, options = {})
  req = build_request(:create_mount_target, params)
  req.send_request(options)
end