Module: Aws::EFS
- Defined in:
- lib/aws-sdk-efs/endpoint_parameters.rb,
sig/client.rbs,
sig/errors.rbs,
sig/waiters.rbs,
sig/resource.rbs,
lib/aws-sdk-efs/plugins/endpoints.rb,
lib/aws-sdk-efs/endpoint_provider.rb,
lib/aws-sdk-efs/client_api.rb,
lib/aws-sdk-efs/endpoints.rb,
lib/aws-sdk-efs/resource.rb,
lib/aws-sdk-efs/errors.rb,
lib/aws-sdk-efs/client.rb,
lib/aws-sdk-efs/types.rb,
lib/aws-sdk-efs.rb
Overview
This module provides support for Amazon Elastic File System. This module is available in the
aws-sdk-efs gem.
Client
The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.
efs = Aws::EFS::Client.new
resp = efs.create_access_point(params)
See Client for more information.
Errors
Errors returned from Amazon Elastic File System are defined in the Errors module and all extend Errors::ServiceError.
begin
# do stuff
rescue Aws::EFS::Errors::ServiceError
# rescues all Amazon Elastic File System API errors
end
See Errors for more information.
Defined Under Namespace
Modules: ClientApi, Endpoints, Errors, Plugins, Types, Waiters Classes: Client, EndpointParameters, EndpointProvider, Resource
service collapse
- GEM_VERSION =
'1.113.0'