Class: Aws::EFS::Types::DescribeAccountPreferencesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-efs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

Present if there are more records than returned in the response. You can use the NextToken in the subsequent request to fetch the additional descriptions.

Returns:



884
885
886
887
888
889
# File 'lib/aws-sdk-efs/types.rb', line 884

class DescribeAccountPreferencesResponse < Struct.new(
  :resource_id_preference,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_id_preferenceTypes::ResourceIdPreference

Describes the resource ID preference setting for the Amazon Web Services account associated with the user making the request, in the current Amazon Web Services Region.

Returns:



884
885
886
887
888
889
# File 'lib/aws-sdk-efs/types.rb', line 884

class DescribeAccountPreferencesResponse < Struct.new(
  :resource_id_preference,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end