Class: Aws::EFS::Types::DescribeFileSystemsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EFS::Types::DescribeFileSystemsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-efs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_token ⇒ String
(Optional) Restricts the list to the file system with this creation token (String).
-
#file_system_id ⇒ String
(Optional) ID of the file system whose description you want to retrieve (String).
-
#marker ⇒ String
(Optional) Opaque pagination token returned from a previous
DescribeFileSystemsoperation (String). -
#max_items ⇒ Integer
(Optional) Specifies the maximum number of file systems to return in the response (integer).
Instance Attribute Details
#creation_token ⇒ String
(Optional) Restricts the list to the file system with this creation token (String). You specify a creation token when you create an Amazon EFS file system.
861 862 863 864 865 866 867 868 |
# File 'lib/aws-sdk-efs/types.rb', line 861 class DescribeFileSystemsRequest < Struct.new( :max_items, :marker, :creation_token, :file_system_id) SENSITIVE = [] include Aws::Structure end |
#file_system_id ⇒ String
(Optional) ID of the file system whose description you want to retrieve (String).
861 862 863 864 865 866 867 868 |
# File 'lib/aws-sdk-efs/types.rb', line 861 class DescribeFileSystemsRequest < Struct.new( :max_items, :marker, :creation_token, :file_system_id) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
(Optional) Opaque pagination token returned from a previous DescribeFileSystems operation (String). If present, specifies to continue the list from where the returning call had left off.
861 862 863 864 865 866 867 868 |
# File 'lib/aws-sdk-efs/types.rb', line 861 class DescribeFileSystemsRequest < Struct.new( :max_items, :marker, :creation_token, :file_system_id) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
(Optional) Specifies the maximum number of file systems to return in the response (integer). This number is automatically set to 100. The response is paginated at 100 per page if you have more than 100 file systems.
861 862 863 864 865 866 867 868 |
# File 'lib/aws-sdk-efs/types.rb', line 861 class DescribeFileSystemsRequest < Struct.new( :max_items, :marker, :creation_token, :file_system_id) SENSITIVE = [] include Aws::Structure end |