Class: Aws::EFS::Types::DescribeMountTargetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EFS::Types::DescribeMountTargetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-efs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_point_id ⇒ String
(Optional) The ID of the access point whose mount targets that you want to list.
-
#file_system_id ⇒ String
(Optional) ID of the file system whose mount targets you want to list (String).
-
#marker ⇒ String
(Optional) Opaque pagination token returned from a previous ‘DescribeMountTargets` operation (String).
-
#max_items ⇒ Integer
(Optional) Maximum number of mount targets to return in the response.
-
#mount_target_id ⇒ String
(Optional) ID of the mount target that you want to have described (String).
Instance Attribute Details
#access_point_id ⇒ String
(Optional) The ID of the access point whose mount targets that you want to list. It must be included in your request if a ‘FileSystemId` or `MountTargetId` is not included in your request. Accepts either an access point ID or ARN as input.
1050 1051 1052 1053 1054 1055 1056 1057 1058 |
# File 'lib/aws-sdk-efs/types.rb', line 1050 class DescribeMountTargetsRequest < Struct.new( :max_items, :marker, :file_system_id, :mount_target_id, :access_point_id) SENSITIVE = [] include Aws::Structure end |
#file_system_id ⇒ String
(Optional) ID of the file system whose mount targets you want to list (String). It must be included in your request if an ‘AccessPointId` or `MountTargetId` is not included. Accepts either a file system ID or ARN as input.
1050 1051 1052 1053 1054 1055 1056 1057 1058 |
# File 'lib/aws-sdk-efs/types.rb', line 1050 class DescribeMountTargetsRequest < Struct.new( :max_items, :marker, :file_system_id, :mount_target_id, :access_point_id) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
(Optional) Opaque pagination token returned from a previous ‘DescribeMountTargets` operation (String). If present, it specifies to continue the list from where the previous returning call left off.
1050 1051 1052 1053 1054 1055 1056 1057 1058 |
# File 'lib/aws-sdk-efs/types.rb', line 1050 class DescribeMountTargetsRequest < Struct.new( :max_items, :marker, :file_system_id, :mount_target_id, :access_point_id) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
(Optional) Maximum number of mount targets to return in the response. Currently, this number is automatically set to 10, and other values are ignored. The response is paginated at 100 per page if you have more than 100 mount targets.
1050 1051 1052 1053 1054 1055 1056 1057 1058 |
# File 'lib/aws-sdk-efs/types.rb', line 1050 class DescribeMountTargetsRequest < Struct.new( :max_items, :marker, :file_system_id, :mount_target_id, :access_point_id) SENSITIVE = [] include Aws::Structure end |
#mount_target_id ⇒ String
(Optional) ID of the mount target that you want to have described (String). It must be included in your request if ‘FileSystemId` is not included. Accepts either a mount target ID or ARN as input.
1050 1051 1052 1053 1054 1055 1056 1057 1058 |
# File 'lib/aws-sdk-efs/types.rb', line 1050 class DescribeMountTargetsRequest < Struct.new( :max_items, :marker, :file_system_id, :mount_target_id, :access_point_id) SENSITIVE = [] include Aws::Structure end |