Class: Aws::EFS::Types::PutFileSystemPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EFS::Types::PutFileSystemPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-efs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bypass_policy_lockout_safety_check ⇒ Boolean
(Optional) A boolean that specifies whether or not to bypass the
FileSystemPolicylockout safety check. -
#file_system_id ⇒ String
The ID of the EFS file system that you want to create or update the
FileSystemPolicyfor. -
#policy ⇒ String
The
FileSystemPolicythat you’re creating.
Instance Attribute Details
#bypass_policy_lockout_safety_check ⇒ Boolean
(Optional) A boolean that specifies whether or not to bypass the FileSystemPolicy lockout safety check. The lockout safety check determines whether the policy in the request will lock out, or prevent, the IAM principal that is making the request from making future PutFileSystemPolicy requests on this file system. Set BypassPolicyLockoutSafetyCheck to True only when you intend to prevent the IAM principal that is making the request from making subsequent PutFileSystemPolicy requests on this file system. The default value is False.
2350 2351 2352 2353 2354 2355 2356 |
# File 'lib/aws-sdk-efs/types.rb', line 2350 class PutFileSystemPolicyRequest < Struct.new( :file_system_id, :policy, :bypass_policy_lockout_safety_check) SENSITIVE = [] include Aws::Structure end |
#file_system_id ⇒ String
The ID of the EFS file system that you want to create or update the FileSystemPolicy for.
2350 2351 2352 2353 2354 2355 2356 |
# File 'lib/aws-sdk-efs/types.rb', line 2350 class PutFileSystemPolicyRequest < Struct.new( :file_system_id, :policy, :bypass_policy_lockout_safety_check) SENSITIVE = [] include Aws::Structure end |
#policy ⇒ String
The FileSystemPolicy that you’re creating. Accepts a JSON formatted policy definition. EFS file system policies have a 20,000 character limit. To find out more about the elements that make up a file system policy, see [Resource-based policies within Amazon EFS].
2350 2351 2352 2353 2354 2355 2356 |
# File 'lib/aws-sdk-efs/types.rb', line 2350 class PutFileSystemPolicyRequest < Struct.new( :file_system_id, :policy, :bypass_policy_lockout_safety_check) SENSITIVE = [] include Aws::Structure end |