Class: Aws::EFS::Types::PutLifecycleConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EFS::Types::PutLifecycleConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-efs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#file_system_id ⇒ String
The ID of the file system for which you are creating the
LifecycleConfigurationobject (String). -
#lifecycle_policies ⇒ Array<Types::LifecyclePolicy>
An array of
LifecyclePolicyobjects that define the file system’sLifecycleConfigurationobject.
Instance Attribute Details
#file_system_id ⇒ String
The ID of the file system for which you are creating the LifecycleConfiguration object (String).
2403 2404 2405 2406 2407 2408 |
# File 'lib/aws-sdk-efs/types.rb', line 2403 class PutLifecycleConfigurationRequest < Struct.new( :file_system_id, :lifecycle_policies) SENSITIVE = [] include Aws::Structure end |
#lifecycle_policies ⇒ Array<Types::LifecyclePolicy>
An array of LifecyclePolicy objects that define the file system’s LifecycleConfiguration object. A LifecycleConfiguration object informs lifecycle management of the following:
-
TransitionToIA– When to move files in the file system from primary storage (Standard storage class) into the Infrequent Access (IA) storage. -
TransitionToArchive– When to move files in the file system from their current storage class (either IA or Standard storage) into the Archive storage.File systems cannot transition into Archive storage before transitioning into IA storage. Therefore, TransitionToArchive must either not be set or must be later than TransitionToIA.
<note markdown=“1”> The Archive storage class is available only for file systems that use the Elastic throughput mode and the General Purpose performance mode.
</note> -
TransitionToPrimaryStorageClass– Whether to move files in the file system back to primary storage (Standard storage class) after they are accessed in IA or Archive storage.
<note markdown=“1”> When using the put-lifecycle-configuration CLI command or the PutLifecycleConfiguration API action, Amazon EFS requires that each LifecyclePolicy object have only a single transition. This means that in a request body, LifecyclePolicies must be structured as an array of LifecyclePolicy objects, one object for each storage transition. See the example requests in the following section for more information.
</note>
2403 2404 2405 2406 2407 2408 |
# File 'lib/aws-sdk-efs/types.rb', line 2403 class PutLifecycleConfigurationRequest < Struct.new( :file_system_id, :lifecycle_policies) SENSITIVE = [] include Aws::Structure end |