Method: Aws::EFS::Client#modify_mount_target_security_groups
- Defined in:
- lib/aws-sdk-efs/client.rb
#modify_mount_target_security_groups(params = {}) ⇒ Struct
Modifies the set of security groups in effect for a mount target.
When you create a mount target, Amazon EFS also creates a new network interface. For more information, see CreateMountTarget. This operation replaces the security groups in effect for the network interface associated with a mount target, with the SecurityGroups provided in the request. This operation requires that the network interface of the mount target has been created and the lifecycle state of the mount target is not deleted.
The operation requires permissions for the following actions:
-
elasticfilesystem:ModifyMountTargetSecurityGroupsaction on the mount target’s file system. -
ec2:ModifyNetworkInterfaceAttributeaction on the mount target’s network interface.
2412 2413 2414 2415 |
# File 'lib/aws-sdk-efs/client.rb', line 2412 def modify_mount_target_security_groups(params = {}, = {}) req = build_request(:modify_mount_target_security_groups, params) req.send_request() end |