Method: Aws::EFS::Types::DescribeFileSystemsRequest#creation_token
- Defined in:
- lib/aws-sdk-efs/types.rb
#creation_token ⇒ String
(Optional) Restricts the list to the file system with this creation token (String). You specify a creation token when you create an Amazon EFS file system.
943 944 945 946 947 948 949 950 |
# File 'lib/aws-sdk-efs/types.rb', line 943 class DescribeFileSystemsRequest < Struct.new( :max_items, :marker, :creation_token, :file_system_id) SENSITIVE = [] include Aws::Structure end |