Class: Aws::EFS::Types::DestinationToCreate
- Inherits:
-
Struct
- Object
- Struct
- Aws::EFS::Types::DestinationToCreate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-efs/types.rb
Overview
Describes the destination file system to create in the replication configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone_name ⇒ String
To create a file system that uses EFS One Zone storage, specify the name of the Availability Zone in which to create the destination file system.
-
#kms_key_id ⇒ String
Specifies the Key Management Service (KMS) key that you want to use to encrypt the destination file system.
-
#region ⇒ String
To create a file system that uses Regional storage, specify the Amazon Web Services Region in which to create the destination file system.
Instance Attribute Details
#availability_zone_name ⇒ String
To create a file system that uses EFS One Zone storage, specify the name of the Availability Zone in which to create the destination file system.
1194 1195 1196 1197 1198 1199 1200 |
# File 'lib/aws-sdk-efs/types.rb', line 1194 class DestinationToCreate < Struct.new( :region, :availability_zone_name, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
Specifies the Key Management Service (KMS) key that you want to use to encrypt the destination file system. If you do not specify a KMS key, Amazon EFS uses your default KMS key for Amazon EFS, /aws/elasticfilesystem. This ID can be in one of the following formats:
-
Key ID - The unique identifier of the key, for example
1234abcd-12ab-34cd-56ef-1234567890ab. -
ARN - The Amazon Resource Name (ARN) for the key, for example
arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab. -
Key alias - A previously created display name for a key, for example
alias/projectKey1. -
Key alias ARN - The ARN for a key alias, for example
arn:aws:kms:us-west-2:444455556666:alias/projectKey1.
1194 1195 1196 1197 1198 1199 1200 |
# File 'lib/aws-sdk-efs/types.rb', line 1194 class DestinationToCreate < Struct.new( :region, :availability_zone_name, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
To create a file system that uses Regional storage, specify the Amazon Web Services Region in which to create the destination file system.
1194 1195 1196 1197 1198 1199 1200 |
# File 'lib/aws-sdk-efs/types.rb', line 1194 class DestinationToCreate < Struct.new( :region, :availability_zone_name, :kms_key_id) SENSITIVE = [] include Aws::Structure end |